# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/transaction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2
from . import amount_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2
from . import account_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/transaction.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n!org/xrpl/rpc/v1/transaction.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1corg/xrpl/rpc/v1/common.proto\x1a\x1corg/xrpl/rpc/v1/amount.proto\x1a\x1dorg/xrpl/rpc/v1/account.proto\"\x8e\x10\n\x0bTransaction\x12)\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Account\x12,\n\x03\x66\x65\x65\x18\x02 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\x12+\n\x08sequence\x18\x03 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.Sequence\x12+\n\x07payment\x18\x04 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.PaymentH\x00\x12\x32\n\x0b\x61\x63\x63ount_set\x18\r \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.AccountSetH\x00\x12\x38\n\x0e\x61\x63\x63ount_delete\x18\x0e \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.AccountDeleteH\x00\x12\x34\n\x0c\x63heck_cancel\x18\x0f \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.CheckCancelH\x00\x12\x30\n\ncheck_cash\x18\x10 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.CheckCashH\x00\x12\x34\n\x0c\x63heck_create\x18\x11 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.CheckCreateH\x00\x12:\n\x0f\x64\x65posit_preauth\x18\x12 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.DepositPreauthH\x00\x12\x36\n\rescrow_cancel\x18\x13 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.EscrowCancelH\x00\x12\x36\n\rescrow_create\x18\x14 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.EscrowCreateH\x00\x12\x36\n\rescrow_finish\x18\x15 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.EscrowFinishH\x00\x12\x43\n\x14nftoken_accept_offer\x18  \x01(\x0b\x32#.org.xrpl.rpc.v1.NFTokenAcceptOfferH\x00\x12\x34\n\x0cnftoken_burn\x18! \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.NFTokenBurnH\x00\x12\x43\n\x14nftoken_cancel_offer\x18\" \x01(\x0b\x32#.org.xrpl.rpc.v1.NFTokenCancelOfferH\x00\x12\x43\n\x14nftoken_create_offer\x18# \x01(\x0b\x32#.org.xrpl.rpc.v1.NFTokenCreateOfferH\x00\x12\x34\n\x0cnftoken_mint\x18$ \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.NFTokenMintH\x00\x12\x34\n\x0coffer_cancel\x18\x16 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.OfferCancelH\x00\x12\x34\n\x0coffer_create\x18\x17 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.OfferCreateH\x00\x12\x45\n\x15payment_channel_claim\x18\x18 \x01(\x0b\x32$.org.xrpl.rpc.v1.PaymentChannelClaimH\x00\x12G\n\x16payment_channel_create\x18\x19 \x01(\x0b\x32%.org.xrpl.rpc.v1.PaymentChannelCreateH\x00\x12\x43\n\x14payment_channel_fund\x18\x1a \x01(\x0b\x32#.org.xrpl.rpc.v1.PaymentChannelFundH\x00\x12\x39\n\x0fset_regular_key\x18\x1b \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.SetRegularKeyH\x00\x12\x39\n\x0fsigner_list_set\x18\x1c \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.SignerListSetH\x00\x12\x36\n\rticket_create\x18\x1e \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.TicketCreateH\x00\x12.\n\ttrust_set\x18\x1d \x01(\x0b\x32\x19.org.xrpl.rpc.v1.TrustSetH\x00\x12=\n\x12signing_public_key\x18\x05 \x01(\x0b\x32!.org.xrpl.rpc.v1.SigningPublicKey\x12\x44\n\x15transaction_signature\x18\x06 \x01(\x0b\x32%.org.xrpl.rpc.v1.TransactionSignature\x12%\n\x05\x66lags\x18\x07 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x12\x41\n\x14last_ledger_sequence\x18\x08 \x01(\x0b\x32#.org.xrpl.rpc.v1.LastLedgerSequence\x12.\n\nsource_tag\x18\t \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.SourceTag\x12$\n\x05memos\x18\n \x03(\x0b\x32\x15.org.xrpl.rpc.v1.Memo\x12(\n\x07signers\x18\x0b \x03(\x0b\x32\x17.org.xrpl.rpc.v1.Signer\x12\x45\n\x16\x61\x63\x63ount_transaction_id\x18\x0c \x01(\x0b\x32%.org.xrpl.rpc.v1.AccountTransactionID\x12\x38\n\x0fticket_sequence\x18\x1f \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.TicketSequenceB\x12\n\x10transaction_data\"\x94\x01\n\x04Memo\x12,\n\tmemo_data\x18\x01 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.MemoData\x12\x30\n\x0bmemo_format\x18\x02 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.MemoFormat\x12,\n\tmemo_type\x18\x03 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.MemoType\"\xb8\x01\n\x06Signer\x12)\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Account\x12\x44\n\x15transaction_signature\x18\x02 \x01(\x0b\x32%.org.xrpl.rpc.v1.TransactionSignature\x12=\n\x12signing_public_key\x18\x03 \x01(\x0b\x32!.org.xrpl.rpc.v1.SigningPublicKey\"\x8f\x03\n\nAccountSet\x12.\n\nclear_flag\x18\x01 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.ClearFlag\x12\'\n\x06\x64omain\x18\x02 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Domain\x12.\n\nemail_hash\x18\x03 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.EmailHash\x12\x30\n\x0bmessage_key\x18\x04 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.MessageKey\x12*\n\x08set_flag\x18\x05 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.SetFlag\x12\x34\n\rtransfer_rate\x18\x06 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.TransferRate\x12,\n\ttick_size\x18\x07 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.TickSize\x12\x36\n\x0enftoken_minter\x18\x08 \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.NFTokenMinter\"|\n\rAccountDelete\x12\x31\n\x0b\x64\x65stination\x18\x01 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.Destination\x12\x38\n\x0f\x64\x65stination_tag\x18\x02 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.DestinationTag\"9\n\x0b\x43heckCancel\x12*\n\x08\x63heck_id\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.CheckID\"\xa6\x01\n\tCheckCash\x12*\n\x08\x63heck_id\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.CheckID\x12)\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.AmountH\x00\x12\x32\n\x0b\x64\x65liver_min\x18\x03 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.DeliverMinH\x00\x42\x0e\n\x0c\x61mount_oneof\"\x87\x02\n\x0b\x43heckCreate\x12\x31\n\x0b\x64\x65stination\x18\x01 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.Destination\x12*\n\x08send_max\x18\x02 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.SendMax\x12\x38\n\x0f\x64\x65stination_tag\x18\x03 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.DestinationTag\x12/\n\nexpiration\x18\x04 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.Expiration\x12.\n\ninvoice_id\x18\x05 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.InvoiceID\"\x8d\x01\n\x0e\x44\x65positPreauth\x12/\n\tauthorize\x18\x01 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.AuthorizeH\x00\x12\x33\n\x0bunauthorize\x18\x02 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.UnauthorizeH\x00\x42\x15\n\x13\x61uthorization_oneof\"m\n\x0c\x45scrowCancel\x12%\n\x05owner\x18\x01 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Owner\x12\x36\n\x0eoffer_sequence\x18\x02 \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.OfferSequence\"\xbb\x02\n\x0c\x45scrowCreate\x12\'\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Amount\x12\x31\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.Destination\x12\x32\n\x0c\x63\x61ncel_after\x18\x03 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.CancelAfter\x12\x32\n\x0c\x66inish_after\x18\x04 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.FinishAfter\x12-\n\tcondition\x18\x05 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.Condition\x12\x38\n\x0f\x64\x65stination_tag\x18\x06 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.DestinationTag\"\xcf\x01\n\x0c\x45scrowFinish\x12%\n\x05owner\x18\x01 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Owner\x12\x36\n\x0eoffer_sequence\x18\x02 \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.OfferSequence\x12-\n\tcondition\x18\x03 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.Condition\x12\x31\n\x0b\x66ulfillment\x18\x04 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.Fulfillment\"\xcf\x01\n\x12NFTokenAcceptOffer\x12=\n\x12nftoken_broker_fee\x18\x01 \x01(\x0b\x32!.org.xrpl.rpc.v1.NFTokenBrokerFee\x12;\n\x11nftoken_buy_offer\x18\x02 \x01(\x0b\x32 .org.xrpl.rpc.v1.NFTokenBuyOffer\x12=\n\x12nftoken_sell_offer\x18\x03 \x01(\x0b\x32!.org.xrpl.rpc.v1.NFTokenSellOffer\"d\n\x0bNFTokenBurn\x12%\n\x05owner\x18\x01 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Owner\x12.\n\nnftoken_id\x18\x02 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.NFTokenID\"D\n\x12NFTokenCancelOffer\x12.\n\x0enftoken_offers\x18\x01 \x03(\x0b\x32\x16.org.xrpl.rpc.v1.Index\"\xf8\x01\n\x12NFTokenCreateOffer\x12\'\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Amount\x12\x31\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.Destination\x12/\n\nexpiration\x18\x03 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.Expiration\x12%\n\x05owner\x18\x04 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Owner\x12.\n\nnftoken_id\x18\x05 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.NFTokenID\"\xc3\x01\n\x0bNFTokenMint\x12\'\n\x06issuer\x18\x01 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Issuer\x12\x34\n\rnftoken_taxon\x18\x02 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.NFTokenTaxon\x12\x32\n\x0ctransfer_fee\x18\x03 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.TransferFee\x12!\n\x03uri\x18\x04 \x01(\x0b\x32\x14.org.xrpl.rpc.v1.URI\"E\n\x0bOfferCancel\x12\x36\n\x0eoffer_sequence\x18\x01 \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.OfferSequence\"\xd6\x01\n\x0bOfferCreate\x12/\n\nexpiration\x18\x01 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.Expiration\x12\x36\n\x0eoffer_sequence\x18\x02 \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.OfferSequence\x12.\n\ntaker_gets\x18\x03 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.TakerGets\x12.\n\ntaker_pays\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.TakerPays\"\xbb\x04\n\x07Payment\x12\'\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Amount\x12\x31\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.Destination\x12\x38\n\x0f\x64\x65stination_tag\x18\x03 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.DestinationTag\x12.\n\ninvoice_id\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.InvoiceID\x12,\n\x05paths\x18\x05 \x03(\x0b\x32\x1d.org.xrpl.rpc.v1.Payment.Path\x12*\n\x08send_max\x18\x06 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.SendMax\x12\x30\n\x0b\x64\x65liver_min\x18\x07 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.DeliverMin\x1a\x9d\x01\n\x0bPathElement\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\x12+\n\x08\x63urrency\x18\x02 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.Currency\x12/\n\x06issuer\x18\x03 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\x1a>\n\x04Path\x12\x36\n\x08\x65lements\x18\x01 \x03(\x0b\x32$.org.xrpl.rpc.v1.Payment.PathElement\"\x91\x02\n\x13PaymentChannelClaim\x12)\n\x07\x63hannel\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Channel\x12)\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Balance\x12\'\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Amount\x12K\n\x19payment_channel_signature\x18\x04 \x01(\x0b\x32(.org.xrpl.rpc.v1.PaymentChannelSignature\x12.\n\npublic_key\x18\x05 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.PublicKey\"\xc4\x02\n\x14PaymentChannelCreate\x12\'\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Amount\x12\x31\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.Destination\x12\x32\n\x0csettle_delay\x18\x03 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.SettleDelay\x12.\n\npublic_key\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.PublicKey\x12\x32\n\x0c\x63\x61ncel_after\x18\x05 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.CancelAfter\x12\x38\n\x0f\x64\x65stination_tag\x18\x06 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.DestinationTag\"\x99\x01\n\x12PaymentChannelFund\x12)\n\x07\x63hannel\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Channel\x12\'\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Amount\x12/\n\nexpiration\x18\x03 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.Expiration\"A\n\rSetRegularKey\x12\x30\n\x0bregular_key\x18\x01 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.RegularKey\"{\n\rSignerListSet\x12\x34\n\rsigner_quorum\x18\x01 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.SignerQuorum\x12\x34\n\x0esigner_entries\x18\x02 \x03(\x0b\x32\x1c.org.xrpl.rpc.v1.SignerEntry\";\n\x0cTicketCreate\x12+\n\x05\x63ount\x18\x01 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.TicketCount\"\xa0\x01\n\x08TrustSet\x12\x32\n\x0climit_amount\x18\x01 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.LimitAmount\x12.\n\nquality_in\x18\x02 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.QualityIn\x12\x30\n\x0bquality_out\x18\x03 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.QualityOutB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2.DESCRIPTOR,])




_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='org.xrpl.rpc.v1.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.Transaction.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee', full_name='org.xrpl.rpc.v1.Transaction.fee', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='org.xrpl.rpc.v1.Transaction.sequence', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment', full_name='org.xrpl.rpc.v1.Transaction.payment', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_set', full_name='org.xrpl.rpc.v1.Transaction.account_set', index=4,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_delete', full_name='org.xrpl.rpc.v1.Transaction.account_delete', index=5,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='check_cancel', full_name='org.xrpl.rpc.v1.Transaction.check_cancel', index=6,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='check_cash', full_name='org.xrpl.rpc.v1.Transaction.check_cash', index=7,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='check_create', full_name='org.xrpl.rpc.v1.Transaction.check_create', index=8,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deposit_preauth', full_name='org.xrpl.rpc.v1.Transaction.deposit_preauth', index=9,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='escrow_cancel', full_name='org.xrpl.rpc.v1.Transaction.escrow_cancel', index=10,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='escrow_create', full_name='org.xrpl.rpc.v1.Transaction.escrow_create', index=11,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='escrow_finish', full_name='org.xrpl.rpc.v1.Transaction.escrow_finish', index=12,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_accept_offer', full_name='org.xrpl.rpc.v1.Transaction.nftoken_accept_offer', index=13,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_burn', full_name='org.xrpl.rpc.v1.Transaction.nftoken_burn', index=14,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_cancel_offer', full_name='org.xrpl.rpc.v1.Transaction.nftoken_cancel_offer', index=15,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_create_offer', full_name='org.xrpl.rpc.v1.Transaction.nftoken_create_offer', index=16,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_mint', full_name='org.xrpl.rpc.v1.Transaction.nftoken_mint', index=17,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offer_cancel', full_name='org.xrpl.rpc.v1.Transaction.offer_cancel', index=18,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offer_create', full_name='org.xrpl.rpc.v1.Transaction.offer_create', index=19,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_channel_claim', full_name='org.xrpl.rpc.v1.Transaction.payment_channel_claim', index=20,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_channel_create', full_name='org.xrpl.rpc.v1.Transaction.payment_channel_create', index=21,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_channel_fund', full_name='org.xrpl.rpc.v1.Transaction.payment_channel_fund', index=22,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_regular_key', full_name='org.xrpl.rpc.v1.Transaction.set_regular_key', index=23,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_list_set', full_name='org.xrpl.rpc.v1.Transaction.signer_list_set', index=24,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ticket_create', full_name='org.xrpl.rpc.v1.Transaction.ticket_create', index=25,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trust_set', full_name='org.xrpl.rpc.v1.Transaction.trust_set', index=26,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signing_public_key', full_name='org.xrpl.rpc.v1.Transaction.signing_public_key', index=27,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_signature', full_name='org.xrpl.rpc.v1.Transaction.transaction_signature', index=28,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.Transaction.flags', index=29,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_ledger_sequence', full_name='org.xrpl.rpc.v1.Transaction.last_ledger_sequence', index=30,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_tag', full_name='org.xrpl.rpc.v1.Transaction.source_tag', index=31,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memos', full_name='org.xrpl.rpc.v1.Transaction.memos', index=32,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signers', full_name='org.xrpl.rpc.v1.Transaction.signers', index=33,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_transaction_id', full_name='org.xrpl.rpc.v1.Transaction.account_transaction_id', index=34,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ticket_sequence', full_name='org.xrpl.rpc.v1.Transaction.ticket_sequence', index=35,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='transaction_data', full_name='org.xrpl.rpc.v1.Transaction.transaction_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=146,
  serialized_end=2208,
)


_MEMO = _descriptor.Descriptor(
  name='Memo',
  full_name='org.xrpl.rpc.v1.Memo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memo_data', full_name='org.xrpl.rpc.v1.Memo.memo_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo_format', full_name='org.xrpl.rpc.v1.Memo.memo_format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memo_type', full_name='org.xrpl.rpc.v1.Memo.memo_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2211,
  serialized_end=2359,
)


_SIGNER = _descriptor.Descriptor(
  name='Signer',
  full_name='org.xrpl.rpc.v1.Signer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.Signer.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_signature', full_name='org.xrpl.rpc.v1.Signer.transaction_signature', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signing_public_key', full_name='org.xrpl.rpc.v1.Signer.signing_public_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2362,
  serialized_end=2546,
)


_ACCOUNTSET = _descriptor.Descriptor(
  name='AccountSet',
  full_name='org.xrpl.rpc.v1.AccountSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear_flag', full_name='org.xrpl.rpc.v1.AccountSet.clear_flag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='org.xrpl.rpc.v1.AccountSet.domain', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email_hash', full_name='org.xrpl.rpc.v1.AccountSet.email_hash', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_key', full_name='org.xrpl.rpc.v1.AccountSet.message_key', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_flag', full_name='org.xrpl.rpc.v1.AccountSet.set_flag', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_rate', full_name='org.xrpl.rpc.v1.AccountSet.transfer_rate', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tick_size', full_name='org.xrpl.rpc.v1.AccountSet.tick_size', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_minter', full_name='org.xrpl.rpc.v1.AccountSet.nftoken_minter', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2549,
  serialized_end=2948,
)


_ACCOUNTDELETE = _descriptor.Descriptor(
  name='AccountDelete',
  full_name='org.xrpl.rpc.v1.AccountDelete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination', full_name='org.xrpl.rpc.v1.AccountDelete.destination', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_tag', full_name='org.xrpl.rpc.v1.AccountDelete.destination_tag', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2950,
  serialized_end=3074,
)


_CHECKCANCEL = _descriptor.Descriptor(
  name='CheckCancel',
  full_name='org.xrpl.rpc.v1.CheckCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='check_id', full_name='org.xrpl.rpc.v1.CheckCancel.check_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3076,
  serialized_end=3133,
)


_CHECKCASH = _descriptor.Descriptor(
  name='CheckCash',
  full_name='org.xrpl.rpc.v1.CheckCash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='check_id', full_name='org.xrpl.rpc.v1.CheckCash.check_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='org.xrpl.rpc.v1.CheckCash.amount', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deliver_min', full_name='org.xrpl.rpc.v1.CheckCash.deliver_min', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='amount_oneof', full_name='org.xrpl.rpc.v1.CheckCash.amount_oneof',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3136,
  serialized_end=3302,
)


_CHECKCREATE = _descriptor.Descriptor(
  name='CheckCreate',
  full_name='org.xrpl.rpc.v1.CheckCreate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination', full_name='org.xrpl.rpc.v1.CheckCreate.destination', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_max', full_name='org.xrpl.rpc.v1.CheckCreate.send_max', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_tag', full_name='org.xrpl.rpc.v1.CheckCreate.destination_tag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='org.xrpl.rpc.v1.CheckCreate.expiration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invoice_id', full_name='org.xrpl.rpc.v1.CheckCreate.invoice_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3305,
  serialized_end=3568,
)


_DEPOSITPREAUTH = _descriptor.Descriptor(
  name='DepositPreauth',
  full_name='org.xrpl.rpc.v1.DepositPreauth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='authorize', full_name='org.xrpl.rpc.v1.DepositPreauth.authorize', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unauthorize', full_name='org.xrpl.rpc.v1.DepositPreauth.unauthorize', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='authorization_oneof', full_name='org.xrpl.rpc.v1.DepositPreauth.authorization_oneof',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3571,
  serialized_end=3712,
)


_ESCROWCANCEL = _descriptor.Descriptor(
  name='EscrowCancel',
  full_name='org.xrpl.rpc.v1.EscrowCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='org.xrpl.rpc.v1.EscrowCancel.owner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offer_sequence', full_name='org.xrpl.rpc.v1.EscrowCancel.offer_sequence', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3714,
  serialized_end=3823,
)


_ESCROWCREATE = _descriptor.Descriptor(
  name='EscrowCreate',
  full_name='org.xrpl.rpc.v1.EscrowCreate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='org.xrpl.rpc.v1.EscrowCreate.amount', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='org.xrpl.rpc.v1.EscrowCreate.destination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_after', full_name='org.xrpl.rpc.v1.EscrowCreate.cancel_after', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finish_after', full_name='org.xrpl.rpc.v1.EscrowCreate.finish_after', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condition', full_name='org.xrpl.rpc.v1.EscrowCreate.condition', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_tag', full_name='org.xrpl.rpc.v1.EscrowCreate.destination_tag', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3826,
  serialized_end=4141,
)


_ESCROWFINISH = _descriptor.Descriptor(
  name='EscrowFinish',
  full_name='org.xrpl.rpc.v1.EscrowFinish',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='org.xrpl.rpc.v1.EscrowFinish.owner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offer_sequence', full_name='org.xrpl.rpc.v1.EscrowFinish.offer_sequence', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condition', full_name='org.xrpl.rpc.v1.EscrowFinish.condition', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fulfillment', full_name='org.xrpl.rpc.v1.EscrowFinish.fulfillment', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4144,
  serialized_end=4351,
)


_NFTOKENACCEPTOFFER = _descriptor.Descriptor(
  name='NFTokenAcceptOffer',
  full_name='org.xrpl.rpc.v1.NFTokenAcceptOffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nftoken_broker_fee', full_name='org.xrpl.rpc.v1.NFTokenAcceptOffer.nftoken_broker_fee', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_buy_offer', full_name='org.xrpl.rpc.v1.NFTokenAcceptOffer.nftoken_buy_offer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_sell_offer', full_name='org.xrpl.rpc.v1.NFTokenAcceptOffer.nftoken_sell_offer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4354,
  serialized_end=4561,
)


_NFTOKENBURN = _descriptor.Descriptor(
  name='NFTokenBurn',
  full_name='org.xrpl.rpc.v1.NFTokenBurn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='org.xrpl.rpc.v1.NFTokenBurn.owner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_id', full_name='org.xrpl.rpc.v1.NFTokenBurn.nftoken_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4563,
  serialized_end=4663,
)


_NFTOKENCANCELOFFER = _descriptor.Descriptor(
  name='NFTokenCancelOffer',
  full_name='org.xrpl.rpc.v1.NFTokenCancelOffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nftoken_offers', full_name='org.xrpl.rpc.v1.NFTokenCancelOffer.nftoken_offers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4665,
  serialized_end=4733,
)


_NFTOKENCREATEOFFER = _descriptor.Descriptor(
  name='NFTokenCreateOffer',
  full_name='org.xrpl.rpc.v1.NFTokenCreateOffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='org.xrpl.rpc.v1.NFTokenCreateOffer.amount', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='org.xrpl.rpc.v1.NFTokenCreateOffer.destination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='org.xrpl.rpc.v1.NFTokenCreateOffer.expiration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner', full_name='org.xrpl.rpc.v1.NFTokenCreateOffer.owner', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_id', full_name='org.xrpl.rpc.v1.NFTokenCreateOffer.nftoken_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4736,
  serialized_end=4984,
)


_NFTOKENMINT = _descriptor.Descriptor(
  name='NFTokenMint',
  full_name='org.xrpl.rpc.v1.NFTokenMint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer', full_name='org.xrpl.rpc.v1.NFTokenMint.issuer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nftoken_taxon', full_name='org.xrpl.rpc.v1.NFTokenMint.nftoken_taxon', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_fee', full_name='org.xrpl.rpc.v1.NFTokenMint.transfer_fee', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='org.xrpl.rpc.v1.NFTokenMint.uri', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4987,
  serialized_end=5182,
)


_OFFERCANCEL = _descriptor.Descriptor(
  name='OfferCancel',
  full_name='org.xrpl.rpc.v1.OfferCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offer_sequence', full_name='org.xrpl.rpc.v1.OfferCancel.offer_sequence', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5184,
  serialized_end=5253,
)


_OFFERCREATE = _descriptor.Descriptor(
  name='OfferCreate',
  full_name='org.xrpl.rpc.v1.OfferCreate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expiration', full_name='org.xrpl.rpc.v1.OfferCreate.expiration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offer_sequence', full_name='org.xrpl.rpc.v1.OfferCreate.offer_sequence', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taker_gets', full_name='org.xrpl.rpc.v1.OfferCreate.taker_gets', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taker_pays', full_name='org.xrpl.rpc.v1.OfferCreate.taker_pays', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5256,
  serialized_end=5470,
)


_PAYMENT_PATHELEMENT = _descriptor.Descriptor(
  name='PathElement',
  full_name='org.xrpl.rpc.v1.Payment.PathElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.Payment.PathElement.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency', full_name='org.xrpl.rpc.v1.Payment.PathElement.currency', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issuer', full_name='org.xrpl.rpc.v1.Payment.PathElement.issuer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5823,
  serialized_end=5980,
)

_PAYMENT_PATH = _descriptor.Descriptor(
  name='Path',
  full_name='org.xrpl.rpc.v1.Payment.Path',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='org.xrpl.rpc.v1.Payment.Path.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5982,
  serialized_end=6044,
)

_PAYMENT = _descriptor.Descriptor(
  name='Payment',
  full_name='org.xrpl.rpc.v1.Payment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='org.xrpl.rpc.v1.Payment.amount', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='org.xrpl.rpc.v1.Payment.destination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_tag', full_name='org.xrpl.rpc.v1.Payment.destination_tag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invoice_id', full_name='org.xrpl.rpc.v1.Payment.invoice_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paths', full_name='org.xrpl.rpc.v1.Payment.paths', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_max', full_name='org.xrpl.rpc.v1.Payment.send_max', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deliver_min', full_name='org.xrpl.rpc.v1.Payment.deliver_min', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PAYMENT_PATHELEMENT, _PAYMENT_PATH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5473,
  serialized_end=6044,
)


_PAYMENTCHANNELCLAIM = _descriptor.Descriptor(
  name='PaymentChannelClaim',
  full_name='org.xrpl.rpc.v1.PaymentChannelClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='org.xrpl.rpc.v1.PaymentChannelClaim.channel', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balance', full_name='org.xrpl.rpc.v1.PaymentChannelClaim.balance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='org.xrpl.rpc.v1.PaymentChannelClaim.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_channel_signature', full_name='org.xrpl.rpc.v1.PaymentChannelClaim.payment_channel_signature', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='org.xrpl.rpc.v1.PaymentChannelClaim.public_key', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6047,
  serialized_end=6320,
)


_PAYMENTCHANNELCREATE = _descriptor.Descriptor(
  name='PaymentChannelCreate',
  full_name='org.xrpl.rpc.v1.PaymentChannelCreate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='org.xrpl.rpc.v1.PaymentChannelCreate.amount', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='org.xrpl.rpc.v1.PaymentChannelCreate.destination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settle_delay', full_name='org.xrpl.rpc.v1.PaymentChannelCreate.settle_delay', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='org.xrpl.rpc.v1.PaymentChannelCreate.public_key', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_after', full_name='org.xrpl.rpc.v1.PaymentChannelCreate.cancel_after', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_tag', full_name='org.xrpl.rpc.v1.PaymentChannelCreate.destination_tag', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6323,
  serialized_end=6647,
)


_PAYMENTCHANNELFUND = _descriptor.Descriptor(
  name='PaymentChannelFund',
  full_name='org.xrpl.rpc.v1.PaymentChannelFund',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='org.xrpl.rpc.v1.PaymentChannelFund.channel', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='org.xrpl.rpc.v1.PaymentChannelFund.amount', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='org.xrpl.rpc.v1.PaymentChannelFund.expiration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6650,
  serialized_end=6803,
)


_SETREGULARKEY = _descriptor.Descriptor(
  name='SetRegularKey',
  full_name='org.xrpl.rpc.v1.SetRegularKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regular_key', full_name='org.xrpl.rpc.v1.SetRegularKey.regular_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6805,
  serialized_end=6870,
)


_SIGNERLISTSET = _descriptor.Descriptor(
  name='SignerListSet',
  full_name='org.xrpl.rpc.v1.SignerListSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signer_quorum', full_name='org.xrpl.rpc.v1.SignerListSet.signer_quorum', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_entries', full_name='org.xrpl.rpc.v1.SignerListSet.signer_entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6872,
  serialized_end=6995,
)


_TICKETCREATE = _descriptor.Descriptor(
  name='TicketCreate',
  full_name='org.xrpl.rpc.v1.TicketCreate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='org.xrpl.rpc.v1.TicketCreate.count', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6997,
  serialized_end=7056,
)


_TRUSTSET = _descriptor.Descriptor(
  name='TrustSet',
  full_name='org.xrpl.rpc.v1.TrustSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit_amount', full_name='org.xrpl.rpc.v1.TrustSet.limit_amount', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality_in', full_name='org.xrpl.rpc.v1.TrustSet.quality_in', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality_out', full_name='org.xrpl.rpc.v1.TrustSet.quality_out', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7059,
  serialized_end=7219,
)

_TRANSACTION.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ACCOUNT
_TRANSACTION.fields_by_name['fee'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
_TRANSACTION.fields_by_name['sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SEQUENCE
_TRANSACTION.fields_by_name['payment'].message_type = _PAYMENT
_TRANSACTION.fields_by_name['account_set'].message_type = _ACCOUNTSET
_TRANSACTION.fields_by_name['account_delete'].message_type = _ACCOUNTDELETE
_TRANSACTION.fields_by_name['check_cancel'].message_type = _CHECKCANCEL
_TRANSACTION.fields_by_name['check_cash'].message_type = _CHECKCASH
_TRANSACTION.fields_by_name['check_create'].message_type = _CHECKCREATE
_TRANSACTION.fields_by_name['deposit_preauth'].message_type = _DEPOSITPREAUTH
_TRANSACTION.fields_by_name['escrow_cancel'].message_type = _ESCROWCANCEL
_TRANSACTION.fields_by_name['escrow_create'].message_type = _ESCROWCREATE
_TRANSACTION.fields_by_name['escrow_finish'].message_type = _ESCROWFINISH
_TRANSACTION.fields_by_name['nftoken_accept_offer'].message_type = _NFTOKENACCEPTOFFER
_TRANSACTION.fields_by_name['nftoken_burn'].message_type = _NFTOKENBURN
_TRANSACTION.fields_by_name['nftoken_cancel_offer'].message_type = _NFTOKENCANCELOFFER
_TRANSACTION.fields_by_name['nftoken_create_offer'].message_type = _NFTOKENCREATEOFFER
_TRANSACTION.fields_by_name['nftoken_mint'].message_type = _NFTOKENMINT
_TRANSACTION.fields_by_name['offer_cancel'].message_type = _OFFERCANCEL
_TRANSACTION.fields_by_name['offer_create'].message_type = _OFFERCREATE
_TRANSACTION.fields_by_name['payment_channel_claim'].message_type = _PAYMENTCHANNELCLAIM
_TRANSACTION.fields_by_name['payment_channel_create'].message_type = _PAYMENTCHANNELCREATE
_TRANSACTION.fields_by_name['payment_channel_fund'].message_type = _PAYMENTCHANNELFUND
_TRANSACTION.fields_by_name['set_regular_key'].message_type = _SETREGULARKEY
_TRANSACTION.fields_by_name['signer_list_set'].message_type = _SIGNERLISTSET
_TRANSACTION.fields_by_name['ticket_create'].message_type = _TICKETCREATE
_TRANSACTION.fields_by_name['trust_set'].message_type = _TRUSTSET
_TRANSACTION.fields_by_name['signing_public_key'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SIGNINGPUBLICKEY
_TRANSACTION.fields_by_name['transaction_signature'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TRANSACTIONSIGNATURE
_TRANSACTION.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_TRANSACTION.fields_by_name['last_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._LASTLEDGERSEQUENCE
_TRANSACTION.fields_by_name['source_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SOURCETAG
_TRANSACTION.fields_by_name['memos'].message_type = _MEMO
_TRANSACTION.fields_by_name['signers'].message_type = _SIGNER
_TRANSACTION.fields_by_name['account_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ACCOUNTTRANSACTIONID
_TRANSACTION.fields_by_name['ticket_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TICKETSEQUENCE
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['payment'])
_TRANSACTION.fields_by_name['payment'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['account_set'])
_TRANSACTION.fields_by_name['account_set'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['account_delete'])
_TRANSACTION.fields_by_name['account_delete'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['check_cancel'])
_TRANSACTION.fields_by_name['check_cancel'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['check_cash'])
_TRANSACTION.fields_by_name['check_cash'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['check_create'])
_TRANSACTION.fields_by_name['check_create'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['deposit_preauth'])
_TRANSACTION.fields_by_name['deposit_preauth'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['escrow_cancel'])
_TRANSACTION.fields_by_name['escrow_cancel'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['escrow_create'])
_TRANSACTION.fields_by_name['escrow_create'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['escrow_finish'])
_TRANSACTION.fields_by_name['escrow_finish'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['nftoken_accept_offer'])
_TRANSACTION.fields_by_name['nftoken_accept_offer'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['nftoken_burn'])
_TRANSACTION.fields_by_name['nftoken_burn'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['nftoken_cancel_offer'])
_TRANSACTION.fields_by_name['nftoken_cancel_offer'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['nftoken_create_offer'])
_TRANSACTION.fields_by_name['nftoken_create_offer'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['nftoken_mint'])
_TRANSACTION.fields_by_name['nftoken_mint'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['offer_cancel'])
_TRANSACTION.fields_by_name['offer_cancel'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['offer_create'])
_TRANSACTION.fields_by_name['offer_create'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['payment_channel_claim'])
_TRANSACTION.fields_by_name['payment_channel_claim'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['payment_channel_create'])
_TRANSACTION.fields_by_name['payment_channel_create'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['payment_channel_fund'])
_TRANSACTION.fields_by_name['payment_channel_fund'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['set_regular_key'])
_TRANSACTION.fields_by_name['set_regular_key'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['signer_list_set'])
_TRANSACTION.fields_by_name['signer_list_set'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['ticket_create'])
_TRANSACTION.fields_by_name['ticket_create'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_TRANSACTION.oneofs_by_name['transaction_data'].fields.append(
  _TRANSACTION.fields_by_name['trust_set'])
_TRANSACTION.fields_by_name['trust_set'].containing_oneof = _TRANSACTION.oneofs_by_name['transaction_data']
_MEMO.fields_by_name['memo_data'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._MEMODATA
_MEMO.fields_by_name['memo_format'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._MEMOFORMAT
_MEMO.fields_by_name['memo_type'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._MEMOTYPE
_SIGNER.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ACCOUNT
_SIGNER.fields_by_name['transaction_signature'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TRANSACTIONSIGNATURE
_SIGNER.fields_by_name['signing_public_key'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SIGNINGPUBLICKEY
_ACCOUNTSET.fields_by_name['clear_flag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CLEARFLAG
_ACCOUNTSET.fields_by_name['domain'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DOMAIN
_ACCOUNTSET.fields_by_name['email_hash'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._EMAILHASH
_ACCOUNTSET.fields_by_name['message_key'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._MESSAGEKEY
_ACCOUNTSET.fields_by_name['set_flag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SETFLAG
_ACCOUNTSET.fields_by_name['transfer_rate'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TRANSFERRATE
_ACCOUNTSET.fields_by_name['tick_size'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TICKSIZE
_ACCOUNTSET.fields_by_name['nftoken_minter'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._NFTOKENMINTER
_ACCOUNTDELETE.fields_by_name['destination'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATION
_ACCOUNTDELETE.fields_by_name['destination_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATIONTAG
_CHECKCANCEL.fields_by_name['check_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CHECKID
_CHECKCASH.fields_by_name['check_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CHECKID
_CHECKCASH.fields_by_name['amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AMOUNT
_CHECKCASH.fields_by_name['deliver_min'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DELIVERMIN
_CHECKCASH.oneofs_by_name['amount_oneof'].fields.append(
  _CHECKCASH.fields_by_name['amount'])
_CHECKCASH.fields_by_name['amount'].containing_oneof = _CHECKCASH.oneofs_by_name['amount_oneof']
_CHECKCASH.oneofs_by_name['amount_oneof'].fields.append(
  _CHECKCASH.fields_by_name['deliver_min'])
_CHECKCASH.fields_by_name['deliver_min'].containing_oneof = _CHECKCASH.oneofs_by_name['amount_oneof']
_CHECKCREATE.fields_by_name['destination'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATION
_CHECKCREATE.fields_by_name['send_max'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SENDMAX
_CHECKCREATE.fields_by_name['destination_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATIONTAG
_CHECKCREATE.fields_by_name['expiration'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._EXPIRATION
_CHECKCREATE.fields_by_name['invoice_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._INVOICEID
_DEPOSITPREAUTH.fields_by_name['authorize'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AUTHORIZE
_DEPOSITPREAUTH.fields_by_name['unauthorize'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._UNAUTHORIZE
_DEPOSITPREAUTH.oneofs_by_name['authorization_oneof'].fields.append(
  _DEPOSITPREAUTH.fields_by_name['authorize'])
_DEPOSITPREAUTH.fields_by_name['authorize'].containing_oneof = _DEPOSITPREAUTH.oneofs_by_name['authorization_oneof']
_DEPOSITPREAUTH.oneofs_by_name['authorization_oneof'].fields.append(
  _DEPOSITPREAUTH.fields_by_name['unauthorize'])
_DEPOSITPREAUTH.fields_by_name['unauthorize'].containing_oneof = _DEPOSITPREAUTH.oneofs_by_name['authorization_oneof']
_ESCROWCANCEL.fields_by_name['owner'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNER
_ESCROWCANCEL.fields_by_name['offer_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OFFERSEQUENCE
_ESCROWCREATE.fields_by_name['amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AMOUNT
_ESCROWCREATE.fields_by_name['destination'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATION
_ESCROWCREATE.fields_by_name['cancel_after'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CANCELAFTER
_ESCROWCREATE.fields_by_name['finish_after'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FINISHAFTER
_ESCROWCREATE.fields_by_name['condition'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CONDITION
_ESCROWCREATE.fields_by_name['destination_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATIONTAG
_ESCROWFINISH.fields_by_name['owner'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNER
_ESCROWFINISH.fields_by_name['offer_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OFFERSEQUENCE
_ESCROWFINISH.fields_by_name['condition'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CONDITION
_ESCROWFINISH.fields_by_name['fulfillment'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FULFILLMENT
_NFTOKENACCEPTOFFER.fields_by_name['nftoken_broker_fee'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._NFTOKENBROKERFEE
_NFTOKENACCEPTOFFER.fields_by_name['nftoken_buy_offer'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._NFTOKENBUYOFFER
_NFTOKENACCEPTOFFER.fields_by_name['nftoken_sell_offer'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._NFTOKENSELLOFFER
_NFTOKENBURN.fields_by_name['owner'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNER
_NFTOKENBURN.fields_by_name['nftoken_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._NFTOKENID
_NFTOKENCANCELOFFER.fields_by_name['nftoken_offers'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._INDEX
_NFTOKENCREATEOFFER.fields_by_name['amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AMOUNT
_NFTOKENCREATEOFFER.fields_by_name['destination'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATION
_NFTOKENCREATEOFFER.fields_by_name['expiration'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._EXPIRATION
_NFTOKENCREATEOFFER.fields_by_name['owner'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNER
_NFTOKENCREATEOFFER.fields_by_name['nftoken_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._NFTOKENID
_NFTOKENMINT.fields_by_name['issuer'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ISSUER
_NFTOKENMINT.fields_by_name['nftoken_taxon'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._NFTOKENTAXON
_NFTOKENMINT.fields_by_name['transfer_fee'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TRANSFERFEE
_NFTOKENMINT.fields_by_name['uri'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._URI
_OFFERCANCEL.fields_by_name['offer_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OFFERSEQUENCE
_OFFERCREATE.fields_by_name['expiration'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._EXPIRATION
_OFFERCREATE.fields_by_name['offer_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OFFERSEQUENCE
_OFFERCREATE.fields_by_name['taker_gets'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TAKERGETS
_OFFERCREATE.fields_by_name['taker_pays'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TAKERPAYS
_PAYMENT_PATHELEMENT.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_PAYMENT_PATHELEMENT.fields_by_name['currency'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._CURRENCY
_PAYMENT_PATHELEMENT.fields_by_name['issuer'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_PAYMENT_PATHELEMENT.containing_type = _PAYMENT
_PAYMENT_PATH.fields_by_name['elements'].message_type = _PAYMENT_PATHELEMENT
_PAYMENT_PATH.containing_type = _PAYMENT
_PAYMENT.fields_by_name['amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AMOUNT
_PAYMENT.fields_by_name['destination'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATION
_PAYMENT.fields_by_name['destination_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATIONTAG
_PAYMENT.fields_by_name['invoice_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._INVOICEID
_PAYMENT.fields_by_name['paths'].message_type = _PAYMENT_PATH
_PAYMENT.fields_by_name['send_max'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SENDMAX
_PAYMENT.fields_by_name['deliver_min'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DELIVERMIN
_PAYMENTCHANNELCLAIM.fields_by_name['channel'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CHANNEL
_PAYMENTCHANNELCLAIM.fields_by_name['balance'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._BALANCE
_PAYMENTCHANNELCLAIM.fields_by_name['amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AMOUNT
_PAYMENTCHANNELCLAIM.fields_by_name['payment_channel_signature'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PAYMENTCHANNELSIGNATURE
_PAYMENTCHANNELCLAIM.fields_by_name['public_key'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PUBLICKEY
_PAYMENTCHANNELCREATE.fields_by_name['amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AMOUNT
_PAYMENTCHANNELCREATE.fields_by_name['destination'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATION
_PAYMENTCHANNELCREATE.fields_by_name['settle_delay'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SETTLEDELAY
_PAYMENTCHANNELCREATE.fields_by_name['public_key'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PUBLICKEY
_PAYMENTCHANNELCREATE.fields_by_name['cancel_after'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CANCELAFTER
_PAYMENTCHANNELCREATE.fields_by_name['destination_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATIONTAG
_PAYMENTCHANNELFUND.fields_by_name['channel'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CHANNEL
_PAYMENTCHANNELFUND.fields_by_name['amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AMOUNT
_PAYMENTCHANNELFUND.fields_by_name['expiration'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._EXPIRATION
_SETREGULARKEY.fields_by_name['regular_key'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._REGULARKEY
_SIGNERLISTSET.fields_by_name['signer_quorum'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SIGNERQUORUM
_SIGNERLISTSET.fields_by_name['signer_entries'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SIGNERENTRY
_TICKETCREATE.fields_by_name['count'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TICKETCOUNT
_TRUSTSET.fields_by_name['limit_amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._LIMITAMOUNT
_TRUSTSET.fields_by_name['quality_in'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._QUALITYIN
_TRUSTSET.fields_by_name['quality_out'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._QUALITYOUT
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['Memo'] = _MEMO
DESCRIPTOR.message_types_by_name['Signer'] = _SIGNER
DESCRIPTOR.message_types_by_name['AccountSet'] = _ACCOUNTSET
DESCRIPTOR.message_types_by_name['AccountDelete'] = _ACCOUNTDELETE
DESCRIPTOR.message_types_by_name['CheckCancel'] = _CHECKCANCEL
DESCRIPTOR.message_types_by_name['CheckCash'] = _CHECKCASH
DESCRIPTOR.message_types_by_name['CheckCreate'] = _CHECKCREATE
DESCRIPTOR.message_types_by_name['DepositPreauth'] = _DEPOSITPREAUTH
DESCRIPTOR.message_types_by_name['EscrowCancel'] = _ESCROWCANCEL
DESCRIPTOR.message_types_by_name['EscrowCreate'] = _ESCROWCREATE
DESCRIPTOR.message_types_by_name['EscrowFinish'] = _ESCROWFINISH
DESCRIPTOR.message_types_by_name['NFTokenAcceptOffer'] = _NFTOKENACCEPTOFFER
DESCRIPTOR.message_types_by_name['NFTokenBurn'] = _NFTOKENBURN
DESCRIPTOR.message_types_by_name['NFTokenCancelOffer'] = _NFTOKENCANCELOFFER
DESCRIPTOR.message_types_by_name['NFTokenCreateOffer'] = _NFTOKENCREATEOFFER
DESCRIPTOR.message_types_by_name['NFTokenMint'] = _NFTOKENMINT
DESCRIPTOR.message_types_by_name['OfferCancel'] = _OFFERCANCEL
DESCRIPTOR.message_types_by_name['OfferCreate'] = _OFFERCREATE
DESCRIPTOR.message_types_by_name['Payment'] = _PAYMENT
DESCRIPTOR.message_types_by_name['PaymentChannelClaim'] = _PAYMENTCHANNELCLAIM
DESCRIPTOR.message_types_by_name['PaymentChannelCreate'] = _PAYMENTCHANNELCREATE
DESCRIPTOR.message_types_by_name['PaymentChannelFund'] = _PAYMENTCHANNELFUND
DESCRIPTOR.message_types_by_name['SetRegularKey'] = _SETREGULARKEY
DESCRIPTOR.message_types_by_name['SignerListSet'] = _SIGNERLISTSET
DESCRIPTOR.message_types_by_name['TicketCreate'] = _TICKETCREATE
DESCRIPTOR.message_types_by_name['TrustSet'] = _TRUSTSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTION,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Transaction)
  })
_sym_db.RegisterMessage(Transaction)

Memo = _reflection.GeneratedProtocolMessageType('Memo', (_message.Message,), {
  'DESCRIPTOR' : _MEMO,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Memo)
  })
_sym_db.RegisterMessage(Memo)

Signer = _reflection.GeneratedProtocolMessageType('Signer', (_message.Message,), {
  'DESCRIPTOR' : _SIGNER,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Signer)
  })
_sym_db.RegisterMessage(Signer)

AccountSet = _reflection.GeneratedProtocolMessageType('AccountSet', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTSET,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.AccountSet)
  })
_sym_db.RegisterMessage(AccountSet)

AccountDelete = _reflection.GeneratedProtocolMessageType('AccountDelete', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTDELETE,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.AccountDelete)
  })
_sym_db.RegisterMessage(AccountDelete)

CheckCancel = _reflection.GeneratedProtocolMessageType('CheckCancel', (_message.Message,), {
  'DESCRIPTOR' : _CHECKCANCEL,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.CheckCancel)
  })
_sym_db.RegisterMessage(CheckCancel)

CheckCash = _reflection.GeneratedProtocolMessageType('CheckCash', (_message.Message,), {
  'DESCRIPTOR' : _CHECKCASH,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.CheckCash)
  })
_sym_db.RegisterMessage(CheckCash)

CheckCreate = _reflection.GeneratedProtocolMessageType('CheckCreate', (_message.Message,), {
  'DESCRIPTOR' : _CHECKCREATE,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.CheckCreate)
  })
_sym_db.RegisterMessage(CheckCreate)

DepositPreauth = _reflection.GeneratedProtocolMessageType('DepositPreauth', (_message.Message,), {
  'DESCRIPTOR' : _DEPOSITPREAUTH,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.DepositPreauth)
  })
_sym_db.RegisterMessage(DepositPreauth)

EscrowCancel = _reflection.GeneratedProtocolMessageType('EscrowCancel', (_message.Message,), {
  'DESCRIPTOR' : _ESCROWCANCEL,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.EscrowCancel)
  })
_sym_db.RegisterMessage(EscrowCancel)

EscrowCreate = _reflection.GeneratedProtocolMessageType('EscrowCreate', (_message.Message,), {
  'DESCRIPTOR' : _ESCROWCREATE,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.EscrowCreate)
  })
_sym_db.RegisterMessage(EscrowCreate)

EscrowFinish = _reflection.GeneratedProtocolMessageType('EscrowFinish', (_message.Message,), {
  'DESCRIPTOR' : _ESCROWFINISH,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.EscrowFinish)
  })
_sym_db.RegisterMessage(EscrowFinish)

NFTokenAcceptOffer = _reflection.GeneratedProtocolMessageType('NFTokenAcceptOffer', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENACCEPTOFFER,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenAcceptOffer)
  })
_sym_db.RegisterMessage(NFTokenAcceptOffer)

NFTokenBurn = _reflection.GeneratedProtocolMessageType('NFTokenBurn', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENBURN,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenBurn)
  })
_sym_db.RegisterMessage(NFTokenBurn)

NFTokenCancelOffer = _reflection.GeneratedProtocolMessageType('NFTokenCancelOffer', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENCANCELOFFER,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenCancelOffer)
  })
_sym_db.RegisterMessage(NFTokenCancelOffer)

NFTokenCreateOffer = _reflection.GeneratedProtocolMessageType('NFTokenCreateOffer', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENCREATEOFFER,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenCreateOffer)
  })
_sym_db.RegisterMessage(NFTokenCreateOffer)

NFTokenMint = _reflection.GeneratedProtocolMessageType('NFTokenMint', (_message.Message,), {
  'DESCRIPTOR' : _NFTOKENMINT,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.NFTokenMint)
  })
_sym_db.RegisterMessage(NFTokenMint)

OfferCancel = _reflection.GeneratedProtocolMessageType('OfferCancel', (_message.Message,), {
  'DESCRIPTOR' : _OFFERCANCEL,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.OfferCancel)
  })
_sym_db.RegisterMessage(OfferCancel)

OfferCreate = _reflection.GeneratedProtocolMessageType('OfferCreate', (_message.Message,), {
  'DESCRIPTOR' : _OFFERCREATE,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.OfferCreate)
  })
_sym_db.RegisterMessage(OfferCreate)

Payment = _reflection.GeneratedProtocolMessageType('Payment', (_message.Message,), {

  'PathElement' : _reflection.GeneratedProtocolMessageType('PathElement', (_message.Message,), {
    'DESCRIPTOR' : _PAYMENT_PATHELEMENT,
    '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
    # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Payment.PathElement)
    })
  ,

  'Path' : _reflection.GeneratedProtocolMessageType('Path', (_message.Message,), {
    'DESCRIPTOR' : _PAYMENT_PATH,
    '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
    # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Payment.Path)
    })
  ,
  'DESCRIPTOR' : _PAYMENT,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Payment)
  })
_sym_db.RegisterMessage(Payment)
_sym_db.RegisterMessage(Payment.PathElement)
_sym_db.RegisterMessage(Payment.Path)

PaymentChannelClaim = _reflection.GeneratedProtocolMessageType('PaymentChannelClaim', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTCHANNELCLAIM,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.PaymentChannelClaim)
  })
_sym_db.RegisterMessage(PaymentChannelClaim)

PaymentChannelCreate = _reflection.GeneratedProtocolMessageType('PaymentChannelCreate', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTCHANNELCREATE,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.PaymentChannelCreate)
  })
_sym_db.RegisterMessage(PaymentChannelCreate)

PaymentChannelFund = _reflection.GeneratedProtocolMessageType('PaymentChannelFund', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTCHANNELFUND,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.PaymentChannelFund)
  })
_sym_db.RegisterMessage(PaymentChannelFund)

SetRegularKey = _reflection.GeneratedProtocolMessageType('SetRegularKey', (_message.Message,), {
  'DESCRIPTOR' : _SETREGULARKEY,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SetRegularKey)
  })
_sym_db.RegisterMessage(SetRegularKey)

SignerListSet = _reflection.GeneratedProtocolMessageType('SignerListSet', (_message.Message,), {
  'DESCRIPTOR' : _SIGNERLISTSET,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SignerListSet)
  })
_sym_db.RegisterMessage(SignerListSet)

TicketCreate = _reflection.GeneratedProtocolMessageType('TicketCreate', (_message.Message,), {
  'DESCRIPTOR' : _TICKETCREATE,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TicketCreate)
  })
_sym_db.RegisterMessage(TicketCreate)

TrustSet = _reflection.GeneratedProtocolMessageType('TrustSet', (_message.Message,), {
  'DESCRIPTOR' : _TRUSTSET,
  '__module__' : 'org.xrpl.rpc.v1.transaction_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TrustSet)
  })
_sym_db.RegisterMessage(TrustSet)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import enum
import math
import typing as t

from xpring import hashes
from xpring.algorithms import ed25519, SigningAlgorithm, SIGNING_ALGORITHMS
from xpring.types import AccountId, Address, EncodedSeed, PublicKey, Seed

ADDRESS_PREFIX = b'\x00'


class Codec:

    def __init__(
        self,
        alphabet='rpshnaf39wBUDNEGHJKLM4PQRST7VWXYZ2bcdeCg65jkm8oFqi1tuvAxyz',
        checksum=hashes.checksum
    ):
        self.alphabet = alphabet
        self.base = len(alphabet)
        self.checksum = checksum

    def encode(self, bites: bytes) -> str:
        zeroes = len(bites)
        sigfig = bites.lstrip(b'\0')
        zeroes -= len(sigfig)
        i = int.from_bytes(sigfig, 'big')
        s = ''
        while i:
            i, digit = divmod(i, self.base)
            s = self.alphabet[digit] + s
        return (self.alphabet[0] * zeroes) + s

    def encode_with_checksum(self, bites: bytes) -> str:
        checksum = self.checksum(bites)
        return self.encode(bites + checksum)

    def encode_seed(
        self, seed: Seed, algorithm: SigningAlgorithm = ed25519
    ) -> str:
        if len(seed) != 16:
            raise ValueError('seed must have exactly 16 bytes of entropy')
        return self.encode_with_checksum(algorithm.SEED_PREFIX + seed)

    def encode_address(self, account_id: AccountId) -> Address:
        return t.cast(
            Address, self.encode_with_checksum(ADDRESS_PREFIX + account_id)
        )

    def decode(self, string: str) -> bytes:
        zeroes = len(string)
        sigfig = string.lstrip(self.alphabet[0])
        zeroes -= len(sigfig)
        number = 0
        for c in sigfig:
            number = number * self.base + self.alphabet.index(c)
        # How many bytes do we need to represent this integer?
        length = math.ceil(math.log(number, 256))
        return (b'\0' * zeroes) + number.to_bytes(length, 'big')

    def decode_with_checksum(self, string: str) -> bytes:
        bites = self.decode(string)
        checksum = bites[-4:]
        payload = bites[:-4]
        if self.checksum(payload) != checksum:
            raise ValueError('wrong checksum')
        return payload

    def decode_seed(
        self,
        encoded_seed: EncodedSeed,
        algorithms: t.Iterable[SigningAlgorithm] = SIGNING_ALGORITHMS
    ) -> t.Tuple[Seed, SigningAlgorithm]:
        payload = self.decode_with_checksum(encoded_seed)
        for algorithm in algorithms:
            if payload.startswith(algorithm.SEED_PREFIX):
                seed = payload[len(algorithm.SEED_PREFIX):]
                return (t.cast(Seed, seed), algorithm)
        raise ValueError('unknown signing algorithm')

    def decode_address(self, address: Address) -> AccountId:
        account_id = self.decode_with_checksum(address)
        return t.cast(AccountId, account_id[len(ADDRESS_PREFIX):])


DEFAULT_CODEC = Codec()



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...
